@@ -1,7 +1,7 @@
 """Package implementation."""
 import functools
 import re
-from typing import List, Optional, Pattern, Set
+from typing import List, Optional, Pattern
 
 from . import config
 
@@ -86,9 +86,9 @@ class TickerExtractor:
 
     def extract(self, text: str) -> List[str]:
         """Return possible tickers extracted from the given text."""
-        blacklist: Set[str] = config.BLACKLIST or set()
         matches = [match.upper() for match in self.pattern.findall(text)]
+        matches = [match for match in matches if match not in config.BLACKLIST]  # Is done _before_ 'mapping'.
+        matches = [config.MAPPING.get(match, match) for match in matches]
         if self.deduplicate:
-            matches = list(dict.fromkeys(matches))
-        matches = [match for match in matches if match not in blacklist]
+            matches = list(dict.fromkeys(matches))  # Is done _after_ 'mapping'.
         return matches
